@@ -1,14 +1,14 @@
-options("rgdal_show_exportToProj4_warnings"="none") 
+
 library('geostatsp')
 
-grd <- GridTopology(c(1,1), c(1,1), c(10,10))
-polys <- as(grd, "SpatialPolygons")
-centroids <- coordinates(polys)
+grd <- rast(extent = c(0,10,0,10), res = c(1,1))
+polys <- as.polygons(grd)
+centroids <- crds(as.points(polys))[seq(from=1, by=4, len=ncell(grd)),]
 x <- centroids[,1]
 y <- centroids[,2]
 z <- 1.4 + 0.1*x + 0.2*y + 0.002*x*x
-xpoly <- SpatialPolygonsDataFrame(polys,
-    data=data.frame(x=x, y=y, z=z, row.names=row.names(polys)))
+xpoly <- polys
+values(xpoly) =data.frame(x=x, y=y, z=z, row.names=row.names(polys))
 
 names(xpoly)=paste("stuff", 
     1:length(names(xpoly)), sep="")
@@ -22,4 +22,5 @@ thebrick = spdfToBrick(
     pattern='^stuff[[:digit:]]$'
     )
     
-plot(thebrick[[1]])    
+plot(thebrick[[1]])   
+
